@@ -1,9 +1,9 @@
 package Pod::From::Acme::CPANModules;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-07-21'; # DATE
+our $DATE = '2021-07-26'; # DATE
 our $DIST = 'Pod-From-Acme-CPANModules'; # DIST
-our $VERSION = '0.010'; # VERSION
+our $VERSION = '0.011'; # VERSION
 
 use 5.010001;
 use strict;
@@ -120,7 +120,11 @@ sub gen_pod_from_acme_cpanmodules {
                      #"$mod_abstracts{$ent->{module}} (from module's Abstract)" :
                      "$mod_abstracts{$ent->{module}}" :
                      undef);
-                $pod .= "=item * L<$ent->{module}>".($summary ? " - $summary" : "")."\n\n";
+                $pod .= "=item L<$ent->{module}>\n\n";
+                if (defined $ent->{summary}) {
+                    require String::PodQuote;
+                    $pod .= String::PodQuote::pod_quote($ent->{summary}) . ".\n\n";
+                }
                 if ($args{entry_description_code}) {
                     my $res;
                     {
@@ -182,7 +186,7 @@ Pod::From::Acme::CPANModules - Generate POD from an Acme::CPANModules::* module
 
 =head1 VERSION
 
-This document describes version 0.010 of Pod::From::Acme::CPANModules (from Perl distribution Pod-From-Acme-CPANModules), released on 2021-07-21.
+This document describes version 0.011 of Pod::From::Acme::CPANModules (from Perl distribution Pod-From-Acme-CPANModules), released on 2021-07-26.
 
 =head1 SYNOPSIS
 
